==> lazy_widget-0.0.2.tar.gz: lib/widget/text_widget.dart <==
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';

/// [Container]
class TextWidget extends StatelessWidget {
  final String text;

  final VoidCallback onPressed;

  final VoidCallback onLongPress;

  final bool visible;

  final InlineSpan textSpan;

  final TextStyle style;

  final StrutStyle strutStyle;

  ///Text()
  final TextAlign textAlign;

  final TextDirection textDirection;

  final Locale locale;

  final bool softWrap;

  final TextOverflow overflow;

  final double textScaleFactor;

  final int maxLines;

  final String semanticsLabel;

  final TextWidthBasis textWidthBasis;

  final TextHeightBehavior textHeightBehavior;

  TextWidget(
    this.text, {
    Key key,
    this.alignment,
    this.padding,
    this.backgroundColor,
    this.decoration,
    this.foregroundDecoration,
    double width,
    double height,
    BoxConstraints constraints,
    this.margin,
    this.transform,

    ///Button
    this.maxLines,
    this.style,
    this.visible,
    this.onPressed,
    this.onLongPress,

    ///Text()
    this.textAlign,
    this.textSpan,
    this.strutStyle,
    this.textDirection,
    this.locale,
    this.softWrap,
    this.overflow,
    this.textScaleFactor,
    this.semanticsLabel,
    this.textWidthBasis,
    this.textHeightBehavior,
  })  : assert(margin == null || margin.isNonNegative),
        assert(padding == null || padding.isNonNegative),
        assert(decoration == null || decoration.debugAssertIsValid()),
        assert(constraints == null || constraints.debugAssertIsValid()),
        constraints = (width != null || height != null)
            ? constraints?.tighten(width: width, height: height) ??
                BoxConstraints.tightFor(width: width, height: height)
            : constraints,
        child = Text(
          (text != null && text.isNotEmpty) ? text : '',
          maxLines: maxLines,
          textAlign: textAlign,
          style: style,
          // textSpan: textSpan,
          strutStyle: strutStyle,
          textDirection: textDirection,
          locale: locale,
          softWrap: softWrap,
          overflow: overflow ?? TextOverflow.ellipsis,
          textScaleFactor: textScaleFactor ?? 1,
          semanticsLabel: semanticsLabel,
          textWidthBasis: textWidthBasis,
          textHeightBehavior: textHeightBehavior,
        ),
        super(key: key);

  final Widget child;

  ///   会覆盖[textAlign]属性，设置后使widget 宽撑满
  final AlignmentGeometry alignment;

  final EdgeInsetsGeometry padding;

  final Decoration decoration;

  final Decoration foregroundDecoration;

  final BoxConstraints constraints;

  final EdgeInsetsGeometry margin;

  final Matrix4 transform;

  final Color backgroundColor;

  EdgeInsetsGeometry get _paddingIncludingDecoration {
    if (decoration == null || decoration.padding == null) return padding;
    final EdgeInsetsGeometry decorationPadding = decoration.padding;
    if (padding == null) return decorationPadding;
    return padding.add(decorationPadding);
  }

  @override
  Widget build(BuildContext context) {
    Widget current = child;

    if (child == null && (constraints == null || !constraints.isTight)) {
      current = LimitedBox(
        maxWidth: 0.0,
        maxHeight: 0.0,
        child: ConstrainedBox(constraints: const BoxConstraints.expand()),
      );
    }

    if (alignment != null)
      current = Align(alignment: alignment, child: current);

    final EdgeInsetsGeometry effectivePadding = _paddingIncludingDecoration;
    if (effectivePadding != null)
      current = Padding(padding: effectivePadding, child: current);

    if (backgroundColor != null)
      current = ColoredBox(color: backgroundColor, child: current);

    if (decoration != null)
      current = DecoratedBox(decoration: decoration, child: current);

    if (foregroundDecoration != null) {
      current = DecoratedBox(
        decoration: foregroundDecoration,
        position: DecorationPosition.foreground,
        child: current,
      );
    }

    if (constraints != null)
      current = ConstrainedBox(constraints: constraints, child: current);

    if (margin != null) current = Padding(padding: margin, child: current);

    if (transform != null)
      current = Transform(transform: transform, child: current);

    if (visible != null) current = Visibility(visible: visible, child: current);

    if (onPressed != null || onLongPress != null)
      current = GestureDetector(
          onTap: onPressed, onLongPress: onPressed, child: current);

    return current;
  }

  @override
  void debugFillProperties(DiagnosticPropertiesBuilder properties) {
    super.debugFillProperties(properties);
    properties.add(DiagnosticsProperty<AlignmentGeometry>(
        'alignment', alignment,
        showName: false, defaultValue: null));
    properties.add(DiagnosticsProperty<EdgeInsetsGeometry>('padding', padding,
        defaultValue: null));
    properties.add(
        DiagnosticsProperty<Decoration>('bg', decoration, defaultValue: null));
    properties.add(DiagnosticsProperty<Decoration>('fg', foregroundDecoration,
        defaultValue: null));
    properties.add(DiagnosticsProperty<BoxConstraints>(
        'constraints', constraints,
        defaultValue: null));
    properties.add(DiagnosticsProperty<EdgeInsetsGeometry>('margin', margin,
        defaultValue: null));
    properties.add(ObjectFlagProperty<Matrix4>.has('transform', transform));
  }

  String toInfo() {
    return 'TextWidget{text: $text, onPressed: $onPressed, onLongPress: $onLongPress, visible: $visible, textSpan: $textSpan, style: $style, strutStyle: $strutStyle, textAlign: $textAlign, textDirection: $textDirection, locale: $locale, softWrap: $softWrap, overflow: $overflow, textScaleFactor: $textScaleFactor, maxLines: $maxLines, semanticsLabel: $semanticsLabel, textWidthBasis: $textWidthBasis, textHeightBehavior: $textHeightBehavior, child: $child, alignment: $alignment, padding: $padding, foregroundDecoration: $foregroundDecoration, constraints: $constraints, margin: $margin}';
  }
}

==> lazy_widget-0.0.3.tar.gz: lib/widget/text_widget.dart <==
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';

/// [Container]
class TextWidget extends StatelessWidget {
  final String text;

  final VoidCallback onPressed;

  final VoidCallback onLongPress;

  final bool visible;

  final InlineSpan textSpan;

  final TextStyle style;

  ///使用的支撑杆样式。撑杆样式定义撑杆，该撑杆设置最小的垂直布局度量
  final StrutStyle strutStyle;

  ///Text()
  ///如何水平对齐
  final TextAlign textAlign;

  final TextDirection textDirection;

  final Locale locale;

  final bool softWrap;

  final TextOverflow overflow;

  final double textScaleFactor;

  final int maxLines;

  final String semanticsLabel;

  final TextWidthBasis textWidthBasis;

  final TextHeightBehavior textHeightBehavior;

  final bool isClipOval;

  final double radius;

  TextWidget(
    this.text, {
    Key key,
    this.alignment,
    this.padding,
    this.backgroundColor,
    this.decoration,
    this.foregroundDecoration,
    double width,
    double height,
    BoxConstraints constraints,
    this.margin,
    this.transform,

    ///
    this.isClipOval,
    this.radius,

    ///Button
    this.maxLines,
    this.style,
    this.visible,
    this.onPressed,
    this.onLongPress,

    ///Text()
    this.textAlign,
    this.textSpan,
    this.strutStyle,
    this.textDirection,
    this.locale,
    this.softWrap,
    this.overflow,
    this.textScaleFactor,
    this.semanticsLabel,
    this.textWidthBasis,
    this.textHeightBehavior,
  })  : assert(margin == null || margin.isNonNegative),
        assert(padding == null || padding.isNonNegative),
        assert(decoration == null || decoration.debugAssertIsValid()),
        assert(constraints == null || constraints.debugAssertIsValid()),
        constraints = (width != null || height != null)
            ? constraints?.tighten(width: width, height: height) ??
                BoxConstraints.tightFor(width: width, height: height)
            : constraints,
        child = Text(
          (text != null && text.isNotEmpty) ? text : '',
          maxLines: maxLines,
          textAlign: textAlign,
          style: style,
          // textSpan: textSpan,
          strutStyle: strutStyle,
          textDirection: textDirection,
          locale: locale,
          softWrap: softWrap,
          overflow: overflow ?? TextOverflow.ellipsis,
          textScaleFactor: textScaleFactor ?? 1,
          semanticsLabel: semanticsLabel,
          textWidthBasis: textWidthBasis,
          textHeightBehavior: textHeightBehavior,
        ),
        super(key: key);

  final Widget child;

  ///   会覆盖[textAlign]属性，设置后使widget 宽撑满
  final AlignmentGeometry alignment;

  final EdgeInsetsGeometry padding;

  final Decoration decoration;

  final Decoration foregroundDecoration;

  final BoxConstraints constraints;

  final EdgeInsetsGeometry margin;

  final Matrix4 transform;

  final Color backgroundColor;

  EdgeInsetsGeometry get _paddingIncludingDecoration {
    if (decoration == null || decoration.padding == null) return padding;
    final EdgeInsetsGeometry decorationPadding = decoration.padding;
    if (padding == null) return decorationPadding;
    return padding.add(decorationPadding);
  }

  @override
  Widget build(BuildContext context) {
    Widget current = child;
    if (current == null && (constraints == null || !constraints.isTight)) {
      current = LimitedBox(
        maxWidth: 0.0,
        maxHeight: 0.0,
        child: ConstrainedBox(constraints: const BoxConstraints.expand()),
      );
    }

    if (alignment != null)
      current = Align(alignment: alignment, child: current);

    final EdgeInsetsGeometry effectivePadding = _paddingIncludingDecoration;
    if (effectivePadding != null)
      current = Padding(padding: effectivePadding, child: current);

    if (backgroundColor != null)
      current = ColoredBox(color: backgroundColor, child: current);

    if (decoration != null)
      current = DecoratedBox(decoration: decoration, child: current);

    if (foregroundDecoration != null) {
      current = DecoratedBox(
        decoration: foregroundDecoration,
        position: DecorationPosition.foreground,
        child: current,
      );
    }

    if (constraints != null)
      current = ConstrainedBox(constraints: constraints, child: current);

    if (onPressed != null || onLongPress != null)
      current = GestureDetector(
          onTap: onPressed, onLongPress: onPressed, child: current);

    if (isClipOval == true) {
      current = ClipOval(
        child: current,
      );
    } else if (radius != null && radius > 0) {
      current = ClipRRect(
        borderRadius: BorderRadius.circular(radius),
        child: current,
      );
    }

    if (margin != null) current = Padding(padding: margin, child: current);

    if (transform != null)
      current = Transform(transform: transform, child: current);

    if (visible != null) current = Visibility(visible: visible, child: current);
    return current;
  }

  @override
  void debugFillProperties(DiagnosticPropertiesBuilder properties) {
    super.debugFillProperties(properties);
    properties.add(DiagnosticsProperty<AlignmentGeometry>(
        'alignment', alignment,
        showName: false, defaultValue: null));
    properties.add(DiagnosticsProperty<EdgeInsetsGeometry>('padding', padding,
        defaultValue: null));
    properties.add(
        DiagnosticsProperty<Decoration>('bg', decoration, defaultValue: null));
    properties.add(DiagnosticsProperty<Decoration>('fg', foregroundDecoration,
        defaultValue: null));
    properties.add(DiagnosticsProperty<BoxConstraints>(
        'constraints', constraints,
        defaultValue: null));
    properties.add(DiagnosticsProperty<EdgeInsetsGeometry>('margin', margin,
        defaultValue: null));
    properties.add(ObjectFlagProperty<Matrix4>.has('transform', transform));
  }

  @override
  String toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) {
    return 'TextWidget{text: $text, onPressed: $onPressed, onLongPress: $onLongPress, visible: $visible, textSpan: $textSpan, style: $style, strutStyle: $strutStyle, textAlign: $textAlign, textDirection: $textDirection, locale: $locale, softWrap: $softWrap, overflow: $overflow, textScaleFactor: $textScaleFactor, maxLines: $maxLines, semanticsLabel: $semanticsLabel, textWidthBasis: $textWidthBasis, textHeightBehavior: $textHeightBehavior, alignment: $alignment, padding: $padding, foregroundDecoration: $foregroundDecoration, constraints: $constraints, margin: $margin,child: $child}';
  }
}
